/*
 * Copyright 1993, 1994, Silicon Graphics, Inc.
 * All Rights Reserved.
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Silicon Graphics, Inc.;
 * the contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Silicon Graphics, Inc.
 *
 * RESTRICTED RIGHTS LEGEND:
 * Use, duplication or disclosure by the Government is subject to restrictions
 * as set forth in subdivision (c)(1)(ii) of the Rights in Technical Data
 * and Computer Software clause at DFARS 252.227-7013, and/or in similar or
 * successor clauses in the FAR, DOD or NASA FAR Supplement. Unpublished -
 * rights reserved under the Copyright Laws of the United States.
 */

/*
 *  checkerboard.c  - open a window, clear the background, and 
 *	render a checkerboard composed of flat shaded rectangles.
 */

#include <GL/gl.h>
#include <GL/glu.h>
#include <aux.h>

/*  Function Prototypes  */

GLvoid  initialize( GLvoid );
GLvoid  drawScene( GLvoid );


void
main()
{
	initialize();

	auxMainLoop( drawScene );
}


GLvoid
initialize( GLvoid )
{
	GLsizei    width, height, winSize;

	auxGetScreenSize( &width, &height );
	winSize = ( width < height ) ? width : height;
	auxInitPosition( winSize / 4, winSize / 4, winSize / 2,
		winSize / 2 );
	auxInitDisplayMode( AUX_RGBA );
	auxInitWindow( "checkerboard" );

	glClearColor( 0.0, 0.0, 1.0, 1.0 );

	glOrtho( -2.0, 2.0, -2.0, 2.0, -1.0, 1.0 );
}


GLvoid
drawScene( GLvoid )
{
	GLboolean   useRed = GL_TRUE;   /* keep track of which color to use */
	GLfloat     x, y;

	static GLfloat    redColor[] = { 1.0, 0.0, 0.0 };
	static GLfloat    blackColor[] = { 0.0, 0.0, 0.0 };

	glClear( GL_COLOR_BUFFER_BIT );

	/* Draw a checkerboard composed of 0.1 by 0.1 rectangles */
	for ( x = -1.0; x < 1.0; x += 0.1 ) {
		useRed = !useRed;
		for ( y = -1.0; y < 1.0; y += 0.1 ) {
			if ( useRed )
				glColor3fv( redColor );
			else
				glColor3fv( blackColor );
			glRectf( x, y, x + 0.1, y + 0.1 );
			useRed = !useRed;
		}
	}

	glFlush();
}
