/*
 * Copyright 1993, 1994, Silicon Graphics, Inc.
 * All Rights Reserved.
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Silicon Graphics, Inc.;
 * the contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Silicon Graphics, Inc.
 *
 * RESTRICTED RIGHTS LEGEND:
 * Use, duplication or disclosure by the Government is subject to restrictions
 * as set forth in subdivision (c)(1)(ii) of the Rights in Technical Data
 * and Computer Software clause at DFARS 252.227-7013, and/or in similar or
 * successor clauses in the FAR, DOD or NASA FAR Supplement. Unpublished -
 * rights reserved under the Copyright Laws of the United States.
 */

/*
 *  squashed.c - show an example of how viewports affect
 *    world space.  We draw the grid from lineGrid.c and
 *    note the how it is affected by the viewport.
 */

#include <GL/gl.h>
#include <GL/glu.h>
#include <aux.h>

/*  Function Prototypes  */

GLvoid  initialize( GLvoid );
GLvoid  drawScene( GLvoid );


void
main()
{
	initialize();

	auxMainLoop( drawScene );
}


GLvoid
initialize( GLvoid )
{
	GLsizei    width, height, winSize;

	auxGetScreenSize( &width, &height );
	winSize = ( width < height ) ? width : height;
	auxInitPosition( winSize / 4, winSize / 4, winSize / 2,
		winSize / 2 );
	auxInitDisplayMode( AUX_RGBA );
	auxInitWindow( "squashed" );

	glClearColor( 1.0, 0.0, 1.0, 1.0 );

	glOrtho( -2.0, 2.0, -2.0, 2.0, -1.0, 1.0 );
}


GLvoid
drawScene( GLvoid )
{
	GLfloat     x, y;
	GLsizei     width, height;

	static GLfloat    greenColor[] = { 0.0, 1.0, 0.0 };
	static GLfloat    blueColor[] = { 0.0, 0.0, 1.0 };
	static GLfloat    whiteColor[] = { 1.0, 1.0, 1.0 };

	glClear( GL_COLOR_BUFFER_BIT );

	auxGetSize( &width, &height );

	glViewport( 0, 0, width, height / 2.0 );

	glColor3fv( blueColor );
	glRectf( -2.0, -2.0, 2.0, 2.0 );

	glColor3fv( whiteColor );	

	/* Draw a square  grid that gets squashed by viewport */
	glBegin( GL_LINES );
	for ( x = -1.0; x < 1.1; x += 0.1 ) {
		glVertex2f( x, -1.0 );
		glVertex2f( x, 1.0 );
	}
	for ( y = -1.0; y < 1.1; y += 0.1 ) {
		glVertex2f( -1.0, y );
		glVertex2f( 1.0, y );
	}
	glEnd();

	glViewport( 0, height / 2.0, width, height / 2.0 );

	glColor3fv( greenColor );
	glRectf( -2.0, -2.0, 2.0, 2.0 );

	glFlush();
}
