/*
 * Copyright 1993, 1994, Silicon Graphics, Inc.
 * All Rights Reserved.
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Silicon Graphics, Inc.;
 * the contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Silicon Graphics, Inc.
 *
 * RESTRICTED RIGHTS LEGEND:
 * Use, duplication or disclosure by the Government is subject to restrictions
 * as set forth in subdivision (c)(1)(ii) of the Rights in Technical Data
 * and Computer Software clause at DFARS 252.227-7013, and/or in similar or
 * successor clauses in the FAR, DOD or NASA FAR Supplement. Unpublished -
 * rights reserved under the Copyright Laws of the United States.
 */

/*
 *  viewport.c  - separate a window into two drawing areas using 
 *      glViewport() and draw rectangles the size of world space
 *      in each.
 */

#include <GL/gl.h>
#include <GL/glu.h>
#include <aux.h>

/*  Function Prototypes  */

GLvoid  initialize( GLvoid );
GLvoid  drawScene( GLvoid );


void
main()
{
	initialize();

	auxMainLoop( drawScene );
}


GLvoid
initialize( GLvoid )
{
	GLsizei    width, height, winSize;

	auxGetScreenSize( &width, &height );
	winSize = ( width < height ) ? width : height;
	auxInitPosition( winSize / 4, winSize / 4, winSize / 2,
		winSize / 2 );
	auxInitDisplayMode( AUX_RGBA );
	auxInitWindow( "viewport" );

	glClearColor( 1.0, 0.0, 1.0, 1.0 );

	glOrtho( -2.0, 2.0, -2.0, 2.0, -1.0, 1.0 );
}


GLvoid
drawScene( GLvoid )
{
	GLsizei    width, height;

	static GLfloat  blueColor[] = { 0.0, 0.0, 1.0 };
	static GLfloat  greenColor[] = { 0.0, 1.0, 0.0 };

	/* Find the size of the window */
	auxGetSize( &width, &height );

	/* Create the first viewport - the bottom half of the screen */
	glViewport( 0, 0, width, height / 2.0 );

	glColor3fv( blueColor );
	glRectf( -2.0, -2.0, 2.0, 2.0 );

	/* Create the second viewport - the top half of the screen */
	glViewport( 0, height / 2.0, width, height / 2.0 );

	glColor3fv( greenColor );
	glRectf( -2.0, -2.0, 2.0, 2.0 );

	glFlush();
}
