/*
 * Copyright 1993, 1994, Silicon Graphics, Inc.
 * All Rights Reserved.
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Silicon Graphics, Inc.;
 * the contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Silicon Graphics, Inc.
 *
 * RESTRICTED RIGHTS LEGEND:
 * Use, duplication or disclosure by the Government is subject to restrictions
 * as set forth in subdivision (c)(1)(ii) of the Rights in Technical Data
 * and Computer Software clause at DFARS 252.227-7013, and/or in similar or
 * successor clauses in the FAR, DOD or NASA FAR Supplement. Unpublished -
 * rights reserved under the Copyright Laws of the United States.
 */

/*
 *  independent.c - draw an egghead using the matrix stack
 *	to isolate the effects of different modeling transformations
 */

#include <GL/gl.h>
#include <GL/glu.h>
#include <aux.h>

/*  Function Prototypes  */

GLvoid  initialize( GLvoid );
GLvoid  drawScene( GLvoid );
GLvoid  resize( GLsizei, GLsizei );

void
main()
{
	initialize();

	auxMainLoop( drawScene );
}

GLvoid
resize( GLsizei width, GLsizei height )
{
	GLfloat    aspect, left, right, bottom, top;

	glViewport( 0, 0, width, height );

	aspect = (GLfloat) width / height;

	/* Set the matrix mode to affect the Projection matrix */
	glMatrixMode( GL_PROJECTION );

	/* Clear the current Projection matrix */
	glLoadIdentity();

	/* Multiply the new perspective projection on the matrix */
	gluPerspective( 45.0, aspect, 3.0, 7.0 );

	/* Return to the ModelView mode */
	glMatrixMode( GL_MODELVIEW );
}

GLvoid
initialize( GLvoid )
{
	GLfloat    aspect;
	GLsizei    width, height;

	auxGetScreenSize( &width, &height );
	auxInitPosition( width / 4, height / 4, width / 2, height / 2 );
	auxInitDisplayMode( AUX_RGBA );
	auxInitWindow( "independent" );

	auxReshapeFunc( resize );

	glClearColor( 0.0, 0.0, 0.0, 1.0 );

	aspect = (GLfloat) width / height;

	/* Set the matrix mode to affect the Projection matrix */
	glMatrixMode( GL_PROJECTION );

	/* Multiply the new perspective projection on the matrix */
	gluPerspective( 45.0, aspect, 3.0, 7.0 );	

	/* Set the matrix mode to affect the ModelView stack */
	glMatrixMode( GL_MODELVIEW );
}

GLvoid
drawScene( GLvoid )
{
	static GLfloat    redColor[] = { 1.0, 0.0, 0.0 };
	static GLfloat    darkgreenColor[] = { 0.0, 0.5, 0.0 };
	static GLfloat    fleshColor[] = { 0.8, 0.5, 0.5 };
	
	glClear( GL_COLOR_BUFFER_BIT );

	/* Save the Identity matrix that's on the ModelView
	 * matrix stack 
	 */
	glPushMatrix();

	  /* Move the origin inside the viewing frustum */
	  glTranslatef( 0.0, 0.0, -4.0 );

	  /* Save the current matrix so we can come back to it later */
	  glPushMatrix();

	    /* A transformation that affects the current matrix */
	    glScalef( 0.75, 1.0, 0.75);
	    glColor3fv( fleshColor );

	    /* Draw an oval face centered at the new origin */
	    auxSolidSphere( 1.0 ); 

	    /* Discard the last transformations, and retrieve 
	     *    the previous current matrix 
	     */
	  glPopMatrix();

          /* Save the current matrix so we can come back to it later */
	  glPushMatrix();

	    /* Move to the top of the head and rotate to draw a hat */
	    glTranslatef( 0.0, 0.5, 0.0 );
	    glRotatef(-90.0, 1.0, 0.0, 0.0 );

	    /* Draw the hat */
	    glColor3fv( darkgreenColor );
	    auxSolidCone( 0.75, 1.0 );

	  glPopMatrix();

	  /* Draw the eyes, nose and mouth */
	  glPointSize( 5.0 );
	  glColor3f( 0.0, 0.0, 0.0 );	 /* black */
	  glBegin( GL_POINTS );
	    glVertex2f( 0.2, 0.1 );
	    glVertex2f( -0.2, 0.1 );
	  glEnd();

	  glBegin( GL_TRIANGLES );
	    glVertex2f( 0.0, 0.0 );
	    glVertex2f( -0.1, -0.3 );
	    glVertex2f( 0.1, -0.3 );
	  glEnd();

	  glColor3fv( redColor );
	  glBegin( GL_LINES );
	    glVertex2f( 0.3, -0.7 );
	    glVertex2f( -0.3, -0.7 );
	  glEnd();
    
	glPopMatrix();

	glFlush();
}
