/*
 * Copyright 1993, 1994, Silicon Graphics, Inc.
 * All Rights Reserved.
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Silicon Graphics, Inc.;
 * the contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Silicon Graphics, Inc.
 *
 * RESTRICTED RIGHTS LEGEND:
 * Use, duplication or disclosure by the Government is subject to restrictions
 * as set forth in subdivision (c)(1)(ii) of the Rights in Technical Data
 * and Computer Software clause at DFARS 252.227-7013, and/or in similar or
 * successor clauses in the FAR, DOD or NASA FAR Supplement. Unpublished -
 * rights reserved under the Copyright Laws of the United States.
 */

/*
 *  translateRotate.c - illustrate what happens when the order
 *      of the modeling transformations is
 *
 *            glTranslate( ... );
 *            glRotate( ... );
 */

#include <GL/gl.h>
#include <GL/glu.h>
#include <aux.h>

/*  Function Prototypes  */

GLvoid  initialize( GLvoid );
GLvoid  drawScene( GLvoid );
GLvoid  resize( GLsizei, GLsizei );
GLvoid  drawAxes( GLvoid );

void
main()
{
	initialize();

	auxMainLoop( drawScene );
}

GLvoid
initialize( GLvoid )
{
	GLfloat    aspect;
	GLsizei    width, height;

	auxGetScreenSize( &width, &height );
	auxInitPosition( 0, height / 4, (width / 2) - 4, height / 2 );
	auxInitDisplayMode( AUX_RGBA );
	auxInitWindow( "translateRotate" );
	auxReshapeFunc( resize );
	glClearColor( 1.0, 0.0, 1.0, 1.0 );

	aspect = (GLfloat) width / height;
	glOrtho( -2.0 * aspect, 2.0 * aspect, -2.0, 2.0, -1.0, 1.0 );
}


GLvoid
resize( GLsizei width, GLsizei height )
{
	GLfloat    aspect, left, right, bottom, top;

	glViewport( 0, 0, width, height );

	aspect = (GLfloat) width / height;

	if ( aspect < 1.0 ) {
		left = -2.0;
		right = 2.0;
		bottom = -2.0 * ( 1.0 / aspect );
		top = 2.0 * ( 1.0 / aspect );
	} else {
		left = -2.0 * aspect;
		right = 2.0 * aspect;
		bottom = -2.0;
		top = 2.0;
	}

	glLoadIdentity();
	glOrtho( left, right, bottom, top, -1.0, 1.0 );
}

GLvoid
drawScene( GLvoid )
{
	GLfloat     x, y;
	GLboolean   useRed = GL_TRUE;

	static GLfloat    redColor[] = { 1.0, 0.0, 0.0 };
	static GLfloat    blackColor[] = { 0.0, 0.0, 0.0 };

	glClear( GL_COLOR_BUFFER_BIT );

	/* Do a translation first, then a rotation */
	glTranslatef( 1.0, 0.0, 0.0 );
	glRotatef( 60.0, 0.0, 0.0, 1.0 );

	for ( x = -1.0; x < 1.0; x += 0.1 ) {
		useRed = !useRed;
		for ( y = -1.0; y < 1.0; y += 0.1 ) {
			if ( useRed )
				glColor3fv( redColor );
			else
				glColor3fv( blackColor );
			glRectf( x, y, x + 0.1, y + 0.1 );
			useRed = !useRed;
		}
	}

	drawAxes();

	glFlush();
}

GLvoid
drawAxes( GLvoid )
{
	glColor3f( 1.0, 1.0, 1.0 );
	glBegin( GL_LINES );
		glVertex2f( 0.0, 0.0 );
		glVertex2f( 1.5, 0.0 );
		glVertex2f( 0.0, 0.0 );
		glVertex2f( 0.0, 1.5 );
	glEnd();

	glBegin( GL_POLYGON );
		glVertex2f( 1.5, 0.0 );
		glVertex2f( 1.35, -0.05 );
		glVertex2f( 1.35, 0.05 );
	glEnd();

	glBegin( GL_POLYGON );
		glVertex2f( 0.0, 1.5 );
		glVertex2f( -0.05, 1.35 );
		glVertex2f( 0.05, 1.35 );
	glEnd();
}
