/*
 * Copyright 1993, 1994, Silicon Graphics, Inc.
 * All Rights Reserved.
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Silicon Graphics, Inc.;
 * the contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Silicon Graphics, Inc.
 *
 * RESTRICTED RIGHTS LEGEND:
 * Use, duplication or disclosure by the Government is subject to restrictions
 * as set forth in subdivision (c)(1)(ii) of the Rights in Technical Data
 * and Computer Software clause at DFARS 252.227-7013, and/or in similar or
 * successor clauses in the FAR, DOD or NASA FAR Supplement. Unpublished -
 * rights reserved under the Copyright Laws of the United States.
 */

/*
 *  flicker.c - illustrate the problem of flicker caused
 *    by animation
 */

#include <GL/gl.h>
#include <GL/glu.h>
#include <aux.h>

/*  Function Prototypes  */

GLvoid  initialize( GLvoid );
GLvoid  drawScene( GLvoid );
GLvoid  resize( GLsizei, GLsizei );
GLvoid  drawGrid( GLvoid );

void polarView( GLdouble, GLdouble, GLdouble, GLdouble );

GLfloat latitude, longitude, radius;

void
main()
{
	initialize();

	auxMainLoop( drawScene );
}

GLvoid
resize( GLsizei width, GLsizei height )
{
	GLfloat    aspect;

	glViewport( 0, 0, width, height );

	aspect = (GLfloat) width / height;

	glMatrixMode( GL_PROJECTION );
	glLoadIdentity();
	gluPerspective( 45.0, aspect, 3.0, 7.0 );
	glMatrixMode( GL_MODELVIEW );
}

GLvoid
initialize( GLvoid )
{
	GLfloat    maxObjectSize, aspect;
	GLdouble   near, far;
	GLsizei    width, height;

	auxGetScreenSize( &width, &height );
	auxInitPosition( width / 4, height / 4, width / 2, height / 2 );
	auxInitDisplayMode( AUX_RGBA | AUX_DEPTH );
	auxInitWindow( "flicker" );

	/* Turn on animation for continuous updating of the window */
	auxAnimation( AUX_ON );

	auxReshapeFunc( resize );

	glClearColor( 0.0, 0.0, 0.0, 1.0 );
	glClearDepth( 1.0 );

	glEnable( GL_DEPTH_TEST );

	glMatrixMode( GL_PROJECTION );
	aspect = (GLfloat) width / height;
	gluPerspective( 45.0, aspect, 3.0, 7.0 );
	glMatrixMode( GL_MODELVIEW );

	near = 3.0;
	far = 7.0;

	maxObjectSize = 3.0;

	radius = near + maxObjectSize / 2.0;

	latitude = 0.0;
	longitude = 0.0;
}

void
polarView( GLdouble radius, GLdouble twist,  GLdouble latitude,
			GLdouble longitude )
{
	glTranslated( 0.0, 0.0, -radius);
	glRotated( -twist, 0.0, 0.0, 1.0 );
	glRotated( -latitude, 1.0, 0.0, 0.0 );
	glRotated( longitude, 0.0, 0.0, 1.0 );
}

GLvoid
drawScene( GLvoid )
{
	static GLfloat    whiteColor[] = { 1.0, 1.0, 1.0 };
	static GLfloat    redColor[] = { 1.0, 0.0, 0.0 };
	static GLfloat    darkGreenColor[] = { 0.0, 0.5, 0.0 };

	glClear( GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT );

	glPushMatrix();

		/* Update the eye's position each frame */
		latitude += 3.0;
		longitude += 2.5;

		polarView( radius, 0, latitude, longitude );

		glColor3fv( redColor );
		auxSolidCone( 0.3, 0.6 );

		glColor3fv( darkGreenColor );
		glPushMatrix();
			glTranslatef( 0.8, -0.65, 0.0 );
			glRotatef( 30.0, 1.0, 0.5, 1.0 );
			auxSolidCylinder( 0.3, 0.6 );
		glPopMatrix();

		glColor3fv( whiteColor );	
		drawGrid();

	glPopMatrix();

	glFlush();
}

GLvoid
drawGrid( GLvoid )
{
	GLfloat     x, y;

	glBegin( GL_LINES );
	for ( x = -1.0; x < 1.1; x += 0.1 ) {
		glVertex2f( x, -1.0 );
		glVertex2f( x, 1.0 );
	}
	for ( y = -1.0; y < 1.1; y += 0.1 ) {
		glVertex2f( -1.0, y );
		glVertex2f( 1.0, y );
	}
	glEnd();
}
