/*
 * Copyright 1993, 1994, Silicon Graphics, Inc.
 * All Rights Reserved.
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Silicon Graphics, Inc.;
 * the contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Silicon Graphics, Inc.
 *
 * RESTRICTED RIGHTS LEGEND:
 * Use, duplication or disclosure by the Government is subject to restrictions
 * as set forth in subdivision (c)(1)(ii) of the Rights in Technical Data
 * and Computer Software clause at DFARS 252.227-7013, and/or in similar or
 * successor clauses in the FAR, DOD or NASA FAR Supplement. Unpublished -
 * rights reserved under the Copyright Laws of the United States.
 */

/*
 *  smoothGouraud.c  - Render some really cool anti-aliased objects
 *     using Gouraud shading.
 *
 *	Escape key 	- exit the program 
 *	`s' key 	- toggle anti-aliasing on / off 
 */

#include <GL/gl.h>
#include <GL/glu.h>
#include <aux.h> 	/* includes <auxDevice.h> */

#include <stdio.h>

/*  Function Prototypes  */

GLvoid  initialize( GLvoid );
GLvoid  drawScene( GLvoid );
GLvoid  resize( GLsizei, GLsizei );
GLvoid  smooth( GLvoid );

void printHelp( char * );

void
main(int argc, char *argv[])
{
	initialize();

	printHelp(argv[0]);

	auxMainLoop( drawScene );
}

void
printHelp( char *progname )
{
        fprintf(stdout, "\n%s\n\n\
	Escape key	- exit the program\n\
	's' Key		- toggle anti-aliasing on / off\n", 
	progname);
}

GLvoid
initialize( GLvoid )
{
	GLsizei    width, height;

	auxGetScreenSize( &width, &height );
	auxInitPosition( width / 4, height / 4, width / 2, height / 2 );
	auxInitDisplayMode( AUX_RGBA );
	auxInitWindow( "smoothGouraud     `s' Key--toggle anti-aliasing" );

	auxReshapeFunc( resize );

	auxKeyFunc( AUX_ESCAPE, auxQuit );

	/* toggle anti-aliasing on/off */
	auxKeyFunc( AUX_s, smooth );

	/* Increase the size of the point so that it doesn't disappear when
	 * anti-aliased */
	glPointSize( 3.5 );

	glLineWidth( 2.5 );

	/* Turn on alpha blending */
	glEnable( GL_BLEND );

	/* Set up the blending function for anti-aliasing */
	glBlendFunc( GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA );

	glClearColor( 0.0, 0.0, 1.0, 1.0 );

	glMatrixMode( GL_PROJECTION );
	glOrtho( 0.0, 1.0, 0.0, 1.0, -1.0, 1.0 );
	glMatrixMode( GL_MODELVIEW );
}


GLvoid
smooth( GLvoid )
{
	static GLboolean   smoothState = GL_FALSE;

	smoothState = !smoothState;

	/* Toggle anti-aliasing for each type of primitive */
	if ( smoothState  == GL_TRUE ) {
		glEnable( GL_POINT_SMOOTH );
		glEnable( GL_LINE_SMOOTH );
		glEnable( GL_POLYGON_SMOOTH );
	} else {
		glDisable( GL_POINT_SMOOTH );
		glDisable( GL_LINE_SMOOTH );
		glDisable( GL_POLYGON_SMOOTH );
	}
}


GLvoid
resize( GLsizei width, GLsizei height )
{
	GLfloat    aspect, left, right, bottom, top;

	glViewport( 0, 0, width, height );

	aspect = (GLfloat) width / height;

	if ( aspect < 1.0 ) {
		left = 0.0;
		right = 1.0;
		bottom = 0.0;
		top = 1.0 / aspect;
	} else {
		left = 0.0;
		right = aspect;
		bottom = 0.0;
		top = 1.0;
	}

	glMatrixMode( GL_PROJECTION );
	glLoadIdentity();
	glOrtho( left, right, bottom, top, -1.0, 1.0 );
	glMatrixMode( GL_MODELVIEW );
}


GLvoid
drawScene( GLvoid )
{
	static GLfloat    whiteColor[] = { 1.0, 1.0, 1.0 };
	static GLfloat    redColor[]  = { 1.0, 0.0, 0.0 };
	static GLfloat    yellowColor[] = { 1.0, 1.0, 0.0 };
	static GLfloat    purpleColor[] = { 1.0, 0.0, 1.0 };
	static GLfloat    darkgreenColor[] = { 0.0, 0.5, 0.0 };
	static GLfloat    blackColor[] = { 0.0, 0.0, 0.0 };
	
	glClear( GL_COLOR_BUFFER_BIT );

	glColor3fv( whiteColor );
	glBegin( GL_POINTS );
	  glVertex2f( 0.3, 0.85 );
	glEnd();

	/* Gouraud shade a line */
	glBegin( GL_LINES );
	  glColor3fv( redColor );
	  glVertex2f( 0.1, 0.1 );
	  glColor3fv( yellowColor );
	  glVertex2f( 0.2, 0.9 );
	glEnd();

	/* Gouraud shade a polygon */
	glBegin( GL_POLYGON );
	  glColor3fv( purpleColor );
	  glVertex2f( 0.5, 0.2 );
	  glColor3fv( darkgreenColor );
	  glVertex2f( 0.8, 0.2 );
	  glColor3fv( blackColor );
	  glVertex2f( 0.6, 0.5 );
	glEnd();

	glFlush();
}
