/*
 * Copyright 1993, 1994, Silicon Graphics, Inc.
 * All Rights Reserved.
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Silicon Graphics, Inc.;
 * the contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Silicon Graphics, Inc.
 *
 * RESTRICTED RIGHTS LEGEND:
 * Use, duplication or disclosure by the Government is subject to restrictions
 * as set forth in subdivision (c)(1)(ii) of the Rights in Technical Data
 * and Computer Software clause at DFARS 252.227-7013, and/or in similar or
 * successor clauses in the FAR, DOD or NASA FAR Supplement. Unpublished -
 * rights reserved under the Copyright Laws of the United States.
 */

/*
 *  text.c - render some text strings using X Window System
 *      fonts and auxRenderFontString()
 */

#include <GL/gl.h>
#include <GL/glu.h>
#include <aux.h>

/*  Function Prototypes  */

GLvoid  initialize( GLvoid );
GLvoid  drawScene( GLvoid );
GLvoid  resize( GLsizei, GLsizei );
GLvoid  drawAxes( GLfloat, GLfloat );

/* Global Variables */
	 
GLint   courierFont, helveticaFont;
char    *charStr = "Howdy!!!";

void
main()
{
	initialize();

	auxMainLoop( drawScene );
}

GLvoid
initialize( GLvoid )
{
	GLfloat    aspect;
	GLsizei    width, height;

	auxGetScreenSize( &width, &height );
	auxInitPosition( width / 4, height / 4, width / 2, height / 2 );
	auxInitDisplayMode( AUX_RGBA | AUX_DOUBLE );
	auxInitWindow( "text" );

	auxAnimation( AUX_ON );

	auxReshapeFunc( resize );

	auxKeyFunc( AUX_ESCAPE, auxQuit );

	glClearColor( 0.0, 0.0, 1.0, 1.0 );

	glMatrixMode( GL_PROJECTION );
	aspect = (GLfloat) width / height;
	glOrtho( -2.0 * aspect, 2.0 * aspect, -2.0, 2.0, -1.0, 1.0 );
	glMatrixMode( GL_MODELVIEW );

	/* Set up two fonts to use for rendering */
	courierFont = 
		auxNewFont( "-*-courier-*-r-*-*-24-*-*-*-*-*-*-*" );
	helveticaFont = 
		auxNewFont( "-*-helvetica-*-*-*-*-24-*-*-*-*-*-*-*" );
}

GLvoid
resize( GLsizei width, GLsizei height )
{
	GLfloat    aspect, left, right, bottom, top;

	glViewport( 0, 0, width, height );

	aspect = (GLfloat) width / height;
	if ( aspect < 1.0 ) {
		left = -2.0;
		right = 2.0;
		bottom = -2.0 * ( 1.0 / aspect );
		top = 2.0 * ( 1.0 / aspect );
	} else {
		left = -2.0 * aspect;
		right = 2.0 * aspect;
		bottom = -2.0;
		top = 2.0;
	}

	glMatrixMode( GL_PROJECTION );
	glLoadIdentity();
	glOrtho( left, right, bottom, top, -1.0, 1.0 );
	glMatrixMode( GL_MODELVIEW );
}


GLvoid
drawAxes( GLfloat x, GLfloat y )
{
	glColor3f( 1.0, 1.0, 1.0 );
	glBegin( GL_LINES );
		glVertex2f( x, y );
		glVertex2f( x+1.0, y );
		glVertex2f( x, y );
		glVertex2f( x, y+1.0 );
	glEnd();
}

GLvoid
drawScene( GLvoid )
{
	char              str[16];
	static GLfloat    whiteColor[] = { 1.0, 1.0, 1.0 };
	static GLfloat    x = 3.0;

	glClear( GL_COLOR_BUFFER_BIT );

	glColor3fv( whiteColor );	

	x -= 0.02;
	if ( x <= -3.0 )
		x = 3.0 ;

	/* Set position for the left end of the baseline for
	 *  our text string */
	glRasterPos2f( x, -1.0 );
	drawAxes( x, -1.0 );
	auxRenderFontString( courierFont, charStr );

	glRasterPos2f( 0.0, -1.5 );
	sprintf( str, "x = %5.2f", x );
	auxRenderFontString( helveticaFont, str );

	auxSwapBuffers();
}
