/*
 * Copyright 1993, 1994, Silicon Graphics, Inc.
 * All Rights Reserved.
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Silicon Graphics, Inc.;
 * the contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Silicon Graphics, Inc.
 *
 * RESTRICTED RIGHTS LEGEND:
 * Use, duplication or disclosure by the Government is subject to restrictions
 * as set forth in subdivision (c)(1)(ii) of the Rights in Technical Data
 * and Computer Software clause at DFARS 252.227-7013, and/or in similar or
 * successor clauses in the FAR, DOD or NASA FAR Supplement. Unpublished -
 * rights reserved under the Copyright Laws of the United States.
 */

/*
 * 2side.c Two-sided lighting and back material example.
 * 
 *		Escape key		- exit the program
 */

#include <aux.h>
#include <math.h>
#include <stdio.h>

/* Function Prototypes */

GLvoid  initialize( GLvoid );
GLvoid  drawScene( GLvoid );
GLvoid  resize( GLsizei, GLsizei );
GLvoid  initLighting( GLvoid );

void polarView( GLdouble, GLdouble, GLdouble, GLdouble );
void printHelp( char * );

/* Global Variables */
GLfloat			latitude, longitude, radius;

GLfloat			fovy = 60.0;	/* Field of view in Y angle */
GLfloat			near = 3.0;	/* Near clipping plane location */
GLfloat			far  = 12.0;	/* Far clipping plane location */

void
main(int argc, char *argv[])
{
	initialize();
	printHelp(argv[0]);
	auxMainLoop( drawScene );
}

GLvoid
initialize( GLvoid )
{
	GLfloat    aspect;
	GLsizei    width, height;

	auxGetScreenSize( &width, &height );
	auxInitPosition( width / 4, height / 4, width / 2,
		height / 2 );
	auxInitDisplayMode( AUX_RGBA | AUX_DEPTH | AUX_DOUBLE );
	auxInitWindow( "2side" );

	auxAnimation( AUX_ON );

	auxReshapeFunc( resize );
	auxKeyFunc( AUX_ESCAPE, auxQuit );

	glClearColor( 0.0, 0.0, 0.0, 1.0 );

	glEnable( GL_DEPTH_TEST );

	glMatrixMode( GL_PROJECTION );
	aspect = (GLfloat) width / height;
	gluPerspective( fovy, aspect, near, far );
	glMatrixMode( GL_MODELVIEW );

	radius = 4.5;
	latitude = -25.0;
	longitude = 0.0;
		
	initLighting();
}

/*  Initialize material property, light source, lighting model, 
 *  and depth buffer.
 */
GLvoid
initLighting( GLvoid )
{
	GLfloat mat_ambient[] = { 0.25, 0.05, 0.4, 1.0 };
	GLfloat mat_diffuse[] = { 0.5, 0.1, 0.8, 1.0 };
	GLfloat mat_diffuse_back[] = { 1.0, 1.0, 0.0, 1.0 };

	/* mat_specular and mat_shininess are NOT default values */
	GLfloat mat_specular[] = { 1.0, 1.0, 1.0, 1.0 };
	GLfloat mat_shininess[] = { 10.0 };
	GLfloat light_position[] = { 1.0, 1.0, 1.0, 0.0 };

	GLfloat lmodel_ambient[] = { 0.2, 0.2, 0.2, 1.0 };
	GLfloat two_side = 1.0;
	
	glMaterialfv(GL_FRONT, GL_AMBIENT, mat_ambient);
	glMaterialfv(GL_FRONT, GL_DIFFUSE, mat_diffuse);
	glMaterialfv(GL_BACK, GL_DIFFUSE, mat_diffuse_back);
	glMaterialfv(GL_FRONT, GL_SPECULAR, mat_specular);
	glMaterialfv(GL_FRONT, GL_SHININESS, mat_shininess);
	glLightfv(GL_LIGHT0, GL_POSITION, light_position);
	glLightModelfv(GL_LIGHT_MODEL_AMBIENT, lmodel_ambient);
	glLightModelf(GL_LIGHT_MODEL_TWO_SIDE, two_side);
	glShadeModel( GL_SMOOTH );

	glEnable(GL_LIGHTING);
	glEnable(GL_LIGHT0);
}

GLvoid
resize( GLsizei width, GLsizei height )
{
	GLfloat     aspect;

	glViewport( 0, 0, width, height );

	aspect = (GLfloat) width / height;

	glMatrixMode( GL_PROJECTION );
	glLoadIdentity();
	aspect = (GLfloat) width / height;
	gluPerspective( fovy, aspect, near, far );
	glMatrixMode( GL_MODELVIEW );
}

void
polarView( GLdouble radius, GLdouble twist,  GLdouble latitude,
				GLdouble longitude )
{
	glTranslated( 0.0, 0.0, -radius);
	glRotated( -twist, 0.0, 0.0, 1.0 );
	glRotated( -latitude, 1.0, 0.0, 0.0 );
	glRotated( longitude, 0.0, 0.0, 1.0 );
}

void
printHelp( char *progname )
{
	fprintf(stdout, "\n%s\n\n\\
	Escape key	- exit the program\n\n", progname);
}

GLvoid
drawScene( GLvoid )
{
	static float spin = 0.0;

	glClear( GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT );

	glPushMatrix();

		polarView( radius, 0, latitude, longitude );

		glPushMatrix();
			glRotatef( spin, 1.0, 1.0, 0.0 );
			auxSolidCylinder( 1.0, 2.0 );
		glPopMatrix();

	glPopMatrix();

	auxSwapBuffers();
	
	spin = fmodf( spin + 3.0, 360.0 );
}
