/*
 * Copyright 1993, 1994, Silicon Graphics, Inc.
 * All Rights Reserved.
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Silicon Graphics, Inc.;
 * the contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Silicon Graphics, Inc.
 *
 * RESTRICTED RIGHTS LEGEND:
 * Use, duplication or disclosure by the Government is subject to restrictions
 * as set forth in subdivision (c)(1)(ii) of the Rights in Technical Data
 * and Computer Software clause at DFARS 252.227-7013, and/or in similar or
 * successor clauses in the FAR, DOD or NASA FAR Supplement. Unpublished -
 * rights reserved under the Copyright Laws of the United States.
 */

/* colorMaterial.c
 *	This program demonstrates using glColorMaterial to quickly 
 *		change material properties.
 *
 *		Escape key		- exit the program
 */

#include <aux.h>
#include <math.h>
#include <stdio.h>

/*  Function Prototypes  */

GLvoid		initialize();
GLvoid		drawScene( GLvoid );
GLvoid		resize( GLsizei width, GLsizei height );
GLvoid		initLighting( GLvoid );

void printHelp( char * );

/* Global Variables */
GLfloat			fovy = 60.0;	/* Field of view in Y angle */
GLfloat			near = 3.0;	/* Near clipping plane location */
GLfloat			far  = 12.0;	/* Far clipping plane location */


void
main(int argc, char *argv[])
{
	initialize();

	printHelp(argv[0]);

	auxMainLoop( drawScene );
}





GLvoid
resize( GLsizei width, GLsizei height )
{
	GLfloat    aspect;

	glViewport( 0, 0, width, height );

	aspect = (GLfloat) width / height;

	glMatrixMode( GL_PROJECTION );
	glLoadIdentity();
	aspect = (GLfloat) width / height;
	gluPerspective( fovy, aspect, near, far );
	glMatrixMode( GL_MODELVIEW );
	glLoadIdentity();
	glTranslatef( 0.0, 0.0, -8.0 ); 
}

GLvoid
initialize( )
{
	GLfloat    aspect;
	GLsizei    width, height;

	auxGetScreenSize( &width, &height );
	auxInitPosition( width / 4, height / 4, width / 2,
		height / 2 );
	auxInitDisplayMode( AUX_RGBA | AUX_DEPTH | AUX_DOUBLE );
	auxInitWindow( "colorMaterial" );
	
	auxReshapeFunc( resize );
	auxAnimation( AUX_ON );

	auxKeyFunc( AUX_ESCAPE, auxQuit );
	
	glClearColor( 0, 0, 0, 1 );
	glEnable( GL_DEPTH_TEST );
	glMatrixMode( GL_PROJECTION );
	aspect = (GLfloat) width / height;
	gluPerspective( fovy, aspect, near, far );
	glMatrixMode( GL_MODELVIEW );
	glTranslatef( 0.0, 0.0, -8.0 );

	initLighting(); 
}

/*  Initialize material property, light source, lighting model, 
 *  and depth buffer.
 */
GLvoid
initLighting( GLvoid )
{

	/* mat_specular and mat_shininess are NOT default values */
	GLfloat mat_specular[] = { 0.8, 0.8, 0.8, 1.0 };
	GLfloat mat_shininess[] = { 10.0 };

	/* light_position is NOT default value	*/
	GLfloat light_position[] = { 1.0, 1.0, 1.0, 0.0 };

	GLfloat lmodel_ambient[] = { 0.2, 0.2, 0.2, 1.0 };

	glMaterialfv(GL_FRONT, GL_SPECULAR, mat_specular);
	glMaterialfv(GL_FRONT, GL_SHININESS, mat_shininess);
	glLightfv(GL_LIGHT0, GL_POSITION, light_position);
	glLightModelfv(GL_LIGHT_MODEL_AMBIENT, lmodel_ambient);
	glShadeModel( GL_SMOOTH );

	glEnable(GL_LIGHTING);
	glEnable(GL_LIGHT0);

	/* changing AMBIENT and DIFFUSE properties to the same value
	 * for the front face only
	 */
	glColorMaterial(GL_FRONT, GL_AMBIENT_AND_DIFFUSE);
	glEnable(GL_COLOR_MATERIAL);
}

void
printHelp( char *progname )
{
	fprintf(stdout, "\n%s\n\n\\
	Escape key			- exit the program\n\n", progname);
}

GLvoid
drawScene( GLvoid )
{
	static GLfloat angle = 0.0;
	int i,  slices = 8;
	
	glClear( GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT );
	glPushMatrix(); 
	
		glRotatef( angle, 0.0, 1.0, 0.0 );
		angle += 0.5;
		if (angle > 360.0)
			angle = 0.0;

		for ( i = 0; i < slices; i++ )
		{
			/* change ambient and diffuse material properties
			 * using GL_COLOR_MATERIAL mode
			 */
			glColor3f( i/10.0, i/10.0, 1.0 - i/10.0 ); 
			glPushMatrix(); 
				glRotatef( i * 360.0/slices, 0, 0, 1 );
				glTranslatef( 1.5, 0.0, 0.0 );
				glRotatef( i * 360.0/slices, 0, 1, 0 );
				auxSolidTorus( 0.25, 0.75 );
			glPopMatrix();
		}
	glPopMatrix();

	auxSwapBuffers();
}
